# SizePred

SizePred is a Python package for predicting clothing sizes based on user inputs like age, gender, height, weight, and other dimensions.

## Installation

You can install SizePred using pip:

```sh
pip install SizePred
